Macro frame_support::dispatch::Eq 1.38.0[−][src]
pub macro Eq($item : item) {
...
}Expand description
Derive macro generating an impl of the trait Eq.
pub macro Eq($item : item) {
...
}Derive macro generating an impl of the trait Eq.