pub trait ClassifyDispatch<T> {
// Required method
fn classify_dispatch(&self, target: T) -> DispatchClass;
}Expand description
Means of classifying a dispatchable function.
Required Methods
Sourcefn classify_dispatch(&self, target: T) -> DispatchClass
fn classify_dispatch(&self, target: T) -> DispatchClass
Classify the dispatch function based on input data target of type T. When implementing
this for a dispatchable, T will be a tuple of all arguments given to the function (except
origin).
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".