Struct frame_support::pallet_prelude::StorageValue [−][src]
pub struct StorageValue<Prefix, Value, QueryKind = OptionQuery, OnEmpty = GetDefault>(_);Expand description
A type that allow to store a value.
Each value is stored at:
Twox128(Prefix::pallet_prefix()) ++ Twox128(Prefix::STORAGE_PREFIX)Implementations
impl<Prefix, Value, QueryKind, OnEmpty> StorageValue<Prefix, Value, QueryKind, OnEmpty> where
Prefix: StorageInstance,
Value: FullCodec,
QueryKind: QueryKindTrait<Value, OnEmpty>,
OnEmpty: Get<QueryKind::Query> + 'static,
impl<Prefix, Value, QueryKind, OnEmpty> StorageValue<Prefix, Value, QueryKind, OnEmpty> where
Prefix: StorageInstance,
Value: FullCodec,
QueryKind: QueryKindTrait<Value, OnEmpty>,
OnEmpty: Get<QueryKind::Query> + 'static,
Get the storage key.
Try to get the underlying value from the provided storage instance; Ok if it exists,
Err if not.
Translate a value from some previous type (O) to the current type.
f: F is the translation function.
Returns Err if the storage item could not be interpreted as the old type, and Ok, along
with the new value if it could.
NOTE: This operates from and to Option<_> types; no effort is made to respect the default
value of the original type.
Warning
This function must be used with care, before being updated the storage still contains the
old type, thus other calls (such as get) will fail at decoding it.
Usage
This would typically be called inside the module implementation of on_runtime_upgrade,
while ensuring no usage of this storage are made before the call to
on_runtime_upgrade. (More precisely prior initialized modules doesn’t make use of this
storage).
Store a value under this key into the provided storage instance.
Store a value under this key into the provided storage instance.
this uses the query type rather than the underlying value.
Mutate the value if closure returns Ok
pub fn append<Item, EncodeLikeItem>(item: EncodeLikeItem) where
Item: Encode,
EncodeLikeItem: EncodeLike<Item>,
Value: StorageAppend<Item>,
pub fn append<Item, EncodeLikeItem>(item: EncodeLikeItem) where
Item: Encode,
EncodeLikeItem: EncodeLike<Item>,
Value: StorageAppend<Item>,
Append the given item to the value in the storage.
Value is required to implement StorageAppend.
Warning
If the storage item is not encoded properly, the storage item will be overwritten
and set to [item]. Any default value set for the storage item will be ignored
on overwrite.
Read the length of the storage value without decoding the entire value.
Value is required to implement StorageDecodeLength.
If the value does not exists or it fails to decode the length, None is returned.
Otherwise Some(len) is returned.
Warning
None does not mean that get() does not return a value. The default value is completly
ignored by this function.
pub fn try_append<Item, EncodeLikeItem>(item: EncodeLikeItem) -> Result<(), ()> where
Item: Encode,
EncodeLikeItem: EncodeLike<Item>,
Value: StorageTryAppend<Item>,
pub fn try_append<Item, EncodeLikeItem>(item: EncodeLikeItem) -> Result<(), ()> where
Item: Encode,
EncodeLikeItem: EncodeLike<Item>,
Value: StorageTryAppend<Item>,
Try and append the given item to the value in the storage.
Is only available if Value of the storage implements StorageTryAppend.