Struct frame_support::pallet_prelude::ValidTransaction [−][src]
pub struct ValidTransaction {
pub priority: u64,
pub requires: Vec<Vec<u8, Global>, Global>,
pub provides: Vec<Vec<u8, Global>, Global>,
pub longevity: u64,
pub propagate: bool,
}Expand description
Information concerning a valid transaction.
Fields
priority: u64Priority of the transaction.
Priority determines the ordering of two transactions that have all their dependencies (required tags) satisfied.
requires: Vec<Vec<u8, Global>, Global>Transaction dependencies
A non-empty list signifies that some other transactions which provide given tags are required to be included before that one.
provides: Vec<Vec<u8, Global>, Global>Provided tags
A list of tags this transaction provides. Successfully importing the transaction will enable other transactions that depend on (require) those tags to be included as well. Provided and required tags allow Substrate to build a dependency graph of transactions and import them in the right (linear) order.
longevity: u64Transaction longevity
Longevity describes minimum number of blocks the validity is correct. After this period transaction should be removed from the pool or revalidated.
propagate: boolA flag indicating if the transaction should be propagated to other peers.
By setting false here the transaction will still be considered for
including in blocks that are authored on the current node, but will
never be sent to other peers.
Implementations
Initiate ValidTransaction builder object with a particular prefix for tags.
To avoid conflicts between different parts in runtime it’s recommended to build requires
and provides tags with a unique prefix.
Combine two instances into one, as a best effort. This will take the superset of each of the
provides and requires tags, it will sum the priorities, take the minimum longevity and
the logic And of the propagate flags.