Struct frame_support::storage::bounded_vec::BoundedVec [−][src]
pub struct BoundedVec<T, S>(_, _);Expand description
A bounded vector.
It has implementations for efficient append and length decoding, as with a normal Vec<_>, once
put into storage as a raw value, map or double-map.
As the name suggests, the length of the queue is always bounded. All internal operations ensure this bound is respected.
Implementations
Consume self, and return the inner Vec. Henceforth, the Vec<_> can be altered in an
arbitrary way. At some point, if the reverse conversion is required, TryFrom<Vec<_>> can
be used.
This is useful for cases if you need access to an internal API of the inner Vec<_> which
is not provided by the wrapper BoundedVec.
pub fn get_mut<I: SliceIndex<[T]>>(
&mut self,
index: I
) -> Option<&mut <I as SliceIndex<[T]>>::Output>
pub fn get_mut<I: SliceIndex<[T]>>(
&mut self,
index: I
) -> Option<&mut <I as SliceIndex<[T]>>::Output>
Exactly the same semantics as slice::get_mut.
Consumes self and mutates self via the given mutate function.
If the outcome of mutation is within bounds, Some(Self) is returned. Else, None is
returned.
This is essentially a consuming shorthand Self::into_inner -> ... ->
Self::try_from.
Exactly the same semantics as Vec::insert, but returns an Err (and is a noop) if the
new length of the vector exceeds S.
Panics
Panics if index > len.
Methods from Deref<Target = Vec<T>>
Returns the number of elements the vector can hold without reallocating.
Examples
let vec: Vec<i32> = Vec::with_capacity(10);
assert_eq!(vec.capacity(), 10);Extracts a slice containing the entire vector.
Equivalent to &s[..].
Examples
use std::io::{self, Write};
let buffer = vec![1, 2, 3, 5, 8];
io::sink().write(buffer.as_slice()).unwrap();Returns a raw pointer to the vector’s buffer.
The caller must ensure that the vector outlives the pointer this function returns, or else it will end up pointing to garbage. Modifying the vector may cause its buffer to be reallocated, which would also make any pointers to it invalid.
The caller must also ensure that the memory the pointer (non-transitively) points to
is never written to (except inside an UnsafeCell) using this pointer or any pointer
derived from it. If you need to mutate the contents of the slice, use as_mut_ptr.
Examples
let x = vec![1, 2, 4];
let x_ptr = x.as_ptr();
unsafe {
for i in 0..x.len() {
assert_eq!(*x_ptr.add(i), 1 << i);
}
}🔬 This is a nightly-only experimental API. (allocator_api)
allocator_api)Returns a reference to the underlying allocator.
Returns the number of elements in the vector, also referred to as its ‘length’.
Examples
let a = vec![1, 2, 3];
assert_eq!(a.len(), 3);Trait Implementations
impl<T, S> Encode for BoundedVec<T, S> where
Vec<T>: Encode,
Vec<T>: Encode,
PhantomData<S>: Encode,
PhantomData<S>: Encode,
impl<T, S> Encode for BoundedVec<T, S> where
Vec<T>: Encode,
Vec<T>: Encode,
PhantomData<S>: Encode,
PhantomData<S>: Encode,
impl<T, S> MaxEncodedLen for BoundedVec<T, S> where
T: MaxEncodedLen,
S: Get<u32>,
BoundedVec<T, S>: Encode,
impl<T, S> MaxEncodedLen for BoundedVec<T, S> where
T: MaxEncodedLen,
S: Get<u32>,
BoundedVec<T, S>: Encode,
Upper bound, in bytes, of the maximum encoded size of this item.
impl<T, S> TypeInfo for BoundedVec<T, S> where
Vec<T>: TypeInfo + 'static,
PhantomData<S>: TypeInfo + 'static,
T: TypeInfo + 'static,
S: 'static,
impl<T, S> TypeInfo for BoundedVec<T, S> where
Vec<T>: TypeInfo + 'static,
PhantomData<S>: TypeInfo + 'static,
T: TypeInfo + 'static,
S: 'static,
impl<T, S> EncodeLike<BoundedVec<T, S>> for BoundedVec<T, S> where
Vec<T>: Encode,
Vec<T>: Encode,
PhantomData<S>: Encode,
PhantomData<S>: Encode,
impl<'a, T: Encode + Decode, S: Get<u32>> EncodeLike<BoundedVec<T, S>> for BoundedSlice<'a, T, S>