Struct frame_support::traits::StorageMapShim [−][src]
pub struct StorageMapShim<S, L, K, T>(_);Expand description
A shim for placing around a storage item in order to use it as a StoredValue. Ideally this
wouldn’t be needed as StorageValues should blanket implement StoredValues, however this
would break the ability to have custom impls of StoredValue. The other workaround is to
implement it directly in the macro.
This form has the advantage that two additional types are provides, Created and Removed,
which are both generic events that can be tied to handlers to do something in the case of being
about to create an account where one didn’t previously exist (at all; not just where it used to
be the default value), or where the account is being removed or reset back to the default value
where previously it did exist (though may have been in a default state). This works well with
system module’s CallOnCreatedAccount and CallKillAccount.