Enum frame_support::weights::DispatchClass [−][src]
pub enum DispatchClass {
Normal,
Operational,
Mandatory,
}Expand description
A generalized group of dispatch types.
NOTE whenever upgrading the enum make sure to also update DispatchClass::all and DispatchClass::non_mandatory helper functions.
Variants
A normal dispatch.
An operational dispatch.
A mandatory dispatch. These kinds of dispatch are always included regardless of their weight, therefore it is critical that they are separately validated to ensure that a malicious validator cannot craft a valid but impossibly heavy block. Usually this just means ensuring that the extrinsic can only be included once and that it is always very light.
Do NOT use it for extrinsics that can be heavy.
The only real use case for this is inherent extrinsics that are required to execute in a block for the block to be valid, and it solves the issue in the case that the block initialization is sufficiently heavy to mean that those inherents do not fit into the block. Essentially, we assume that in these exceptional circumstances, it is better to allow an overweight block to be created than to not allow any block at all to be created.
Implementations
Returns an array containing all dispatch classes.