Struct frame_support::weights::FunctionOf [−][src]
pub struct FunctionOf<WD, CD, PF>(pub WD, pub CD, pub PF);Function arguments are available directly inside the annotation now.
A struct to represent a weight which is a function of the input arguments. The given items have the following types:
WD: a rawWeightvalue or a closure that returns aWeightwith the same argument list as the dispatched, wrapped in a tuple.CD: a rawDispatchClassvalue or a closure that returns aDispatchClasswith the same argument list as the dispatched, wrapped in a tuple.PF: aPaysvariant for whether this dispatch pays fee or not or a closure that returns aPaysvariant with the same argument list as the dispatched, wrapped in a tuple.
Tuple Fields
0: WDFunction arguments are available directly inside the annotation now.
1: CDFunction arguments are available directly inside the annotation now.
2: PFFunction arguments are available directly inside the annotation now.