Struct frame_support::weights::PerDispatchClass [−][src]
pub struct PerDispatchClass<T> { /* fields omitted */ }Expand description
A struct holding value for each DispatchClass.
Implementations
Create new PerDispatchClass with the same value for every class.
Get a mutable reference to current value of given class.
Get current value for given class.
Set the value of given class.
Add some weight of a specific dispatch class, saturating at the numeric bounds of Weight.
Try to add some weight of a specific dispatch class, returning Err(()) if overflow would occur.
Subtract some weight of a specific dispatch class, saturating at the numeric bounds of
Weight.