Struct frame_support::weights::PostDispatchInfo [−][src]
Weight information that is only available post dispatch. NOTE: This can only be used to reduce the weight or fee, not increase it.
Fields
actual_weight: Option<Weight>Actual weight consumed by a call or None which stands for the worst case static weight.
pays_fee: PaysWhether this transaction should pay fees when all is said and done.
Implementations
Calculate how much (if any) weight was not used by the Dispatchable.
Calculate how much weight was actually spent by the Dispatchable.
Determine if user should actually pay fees at the end of the dispatch.