OneOrMany

Trait OneOrMany 

pub trait OneOrMany<T> {
    type Iter: Iterator<Item = T>;

    // Required method
    fn into_iter(self) -> Self::Iter;
}
A trait that represents one or many values of given type.

Useful to accept as parameter type to let the caller pass either a single value directly or an iterator.

Required Associated Types

type Iter: Iterator<Item = T>

The iterator type.

Required Methods

fn into_iter(self) -> Self::Iter

Convert this item into an iterator.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<'a> OneOrMany<DispatchClass> for &'a [DispatchClass]

Implementors