pub trait Parameter:
Codec
+ DecodeWithMemTracking
+ EncodeLike
+ Clone
+ Eq
+ Debug
+ TypeInfo { }Expand description
A type that can be used as a parameter in a dispatchable function.
When using decl_module all arguments for call functions must implement this trait.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".